---
title: "Introduction"
type: Chapter
slug: true
front: false
---

>> The real long-term future of computing consists of figuring out how to make the best possible use we can out of the literal millions of devices which already exist.

<cite>(Solderpunk, 2020, Cited in de Valk, 2022)</cite>

I am a big fan of thinkering with electronics. I think it creates a creative mindset that allows you to hack, modify and own the devices. But I’ve also grown a certain discomfort with the practices, first started with a ) the amount of waste I was creating just for a funky explorative session and b) the lack of “respect” there was for the material. 



You're reading[^shortcut-print] *A Field Guide for Salvaging Sound Devices*. Here, we'll explore the practical side of salvage computing through the making of noise boxes: is it possible to *live off* (create with) electronic components salvaged in the wild? And what would such a practice entail?

[^shortcut-print]: <kbd>Ctrl</kbd> + <kbd>P</kbd> to print this publication to bring it outside

Salvaging is the practice of using computational resources that already exist. Not freshly purchased hardware, but salvaged from landfills and hidden in storage boxes. Salvage computing believes that the end of a product's lifecycle should be a moment of celebration—not a time of death, but an opportunity to start something new [@lulinvegaHolisticApproachComputing]. These ideas offer an exciting new perspective; instead of presenting e-waste as a wicked, unmanageable problem [@baldeGlobalEWasteMonitor2024], it is seen as untapped potential and an opportunity to explore. It could offer an alternative to the problems I’ve been facing in my own practice and might help you too. 

### Dealing with my own waste
Over the past years, I’ve hosted workshops around circuit bending[^circuit-bending] in and around Rotterdam. These workshops are meant as an accessible way to get people tinkering with electronics[^tinkering], through something infinitely playful: making instruments[^playful]. Unfortunately, I cannot ignore the waste these workshops create any longer, as they creep up in my workspace. The toys used in the workshops are single-use [^single-use] and, with ease, thrown out afterwards. The carelessness notion creeps in that waste has no value, and is easily replaceable, and low-key broke my heart a bit, one workshop at a time.

TODO: One sentence about blackboxism and consumer culture

[^circuit-bending]: the practice around hacking discarded toys to find sonic potential through creating shorts, or sometimes literally bending the circuit.

[^playful]: I’ve found that making instruments is a great way to learn about and work with the *flow* of electricity, but more on that later.

[^single-use]: but often required much preparation in terms of collecting, transporting, repairing, testing, cleaning, prepare.

This is where the field guide comes into play: can we flip this practice of playful tinkering to not ignore the waste streams they are part of but make it part of their lifespan?  Is engaging with the waste streams[^waste-streams] a way to reduce the carelessness? 

[^waste-streams]: on the contrary of neatly prepping everything beforehand and being in charge of the cleaning afterward.

The guide is split up into five chapters, each focusing on a different stage of salvaging for sound devices:

#### 1. Gathering hardware
*We'll go through which devices work for salvaging, and where to find them. And talk about dealing with hidden waste streams and obsolescence.*

#### 2. Dismantling devices
*Hands-on discovery of strategies that manufacturers use to keep you out of their devices, and the right to repair. Hopefully not too much melted plastic.*

#### 3. Components to salvage
*An overview of parts to salvage, how to identify them, and how to reuse them*

#### 4. Recipes for making
*strategies for making with salvaged parts, and ways to modify the devices.*

#### 5. Taking inventory
*Cleaning up the inventory and looking back*


Because salvage is not just about reusing materials; but about confronting the systems that created the waste in the first place. Waste is not only your end-of-life Humane AI Pin[^AI-pin] but also the by-product of the entire production lifecycle of an electronic product; From the mining of minerals that make up the hardware to the inevitable disposal site [@gabrysSalvage2012]. Since the rate at which waste is collected and recycled isn't growing at the same pace as our collective buying and production, the landfills will continue to grow. The capitalist market is simply too focused on buying and producing new products.

[^AI-pin]: Humane Inc. Ai Pin closed their servers within one year after releasing their “Ai Pin”. Now, you can only ask this piece of hardware how many batteries it has left. [@chokkattuWhatYourDefunct2025]

## Buying DIY
The preference for buying new is noticeable in the DIY synth community as well. When publishing about a project it's common to share a pre-filled webshop cart along with the schematics, or even sell it as a pre-compiled kit[^KIT]. To me, this goes against the ethos of DIY, which is about making do with limited budget & resources [@hertzArtDIYElectronics2023]. Instead, a whole new market is created consisting of Lego-like kits. These kits gloss over the actual challenges and difficulties of creating sound boxes, preventing the development of much-needed problem-solving skills, and not actually discovering anything new [@CooperativeExperimentalismSharing].

[^KIT]: ![Kit from Bastl Instruments](/assets/chapters/bastl_kit.webp)


## Do It With Others (DIWO)
Repair is often and historically organized as a social activity - opening up workplaces and sharing knowledge[@matternStepStepThinking2024].  This notion is a major part of the DIY Synth community [@richardsDIYElectronicMusic2013]. By being part of workshops and gatherings around DIY sound and repair I've noticed how empowering these exchanges can be [^exchange]. This guide itself is created during and around so-called *(un)repair nights[^unrepair-night]* at the klankschool[^about-klankschool]. I would really encourage you to do DIWO this guide too. The frustrating process that can be learning electronics is much better to manage when shared.

[^exchange]: Especially during a [workshop in collaboration with the kunsthal](https://www.kunsthal.nl/nl/plan-je-bezoek/activiteiten/friday-night-live-operator/), where it was the first time making a circuit for many attendees. It was great to see how people without much electronics experience, figured out circuit making and playing, together.

[^unrepair-night]: The (un)repair cafe is a by-weekly hangout at the Klankschool, where we modify, hack, and repair devices. Check the [calendar](https://calendar.klank.school/) for the next event!

[^about-klankschool]: Klankschool is a loose-knit group of sonic practitioners based in Rotterdam who share a common interest in performances, sound art, improvisation, and noise. Everyone involved is a teacher, student, musician, janitor, and more.

On that note, I am by no means an expert in electronics. When I write about how things work, please take it with a grain of salt. This guide represents my personal understanding, which, no doubt, contains incorrect assumptions or oversimplifications. If you have suggestions for improvement, feel free to reach out!

<ins> De buying DIY komt niet helemaal lekker meer in hier nu</ins>
<ins>Nadenken over hoe je je inmiddels verhoudt tot de DIWO</ins>

<!-- #### Heeft nog geen plek

1. The E-Waste Monitor shows that global e-waste production is growing rapidly, even doubling between 2010 and 2022.[@baldeGlobalEWasteMonitor2024] 
2. Ik denk dat hier ook verder de urgency in zit. De gesprekken die ik de afgelopen maanden heb gehad lieten daar ook zien dat het nog steeds gangbaar is om nieuw te kopen, terwijl er tegelijkertijd zo ontiegelijk veel wordt weggegooid. Met de qutoe als kers op de taart van de mileupark medewerker die inscahtte dat 90% van de apparaten die bij hem voorbij kwamen het nog zouden doen. Voor mij is dat 90% aan wasted oppurtunities om te leren en te kutten met electronics. 
3. <ins>uitkomst gaat denk ik zijn delen en therefore the parts exchange</ins>
4. These transitions happen in hazardous waste sites, causing long-term environmental and health problems, often in developing countries where technology consumption is much lower. 
5. The growing gap between recycling and production can be traced to several factors: increased consumption of technology, limited repair options, and a lacking e-waste infrastructure
6. I’ve set the limitation to not buy new parts and components (or dip into an existing inventory), and encourage you to do the same, throughout the following of this guide. -->